The package provides methods to calculate and interpret climate change
signals and time series from entire multi-model ensembles. Climate
model output in binary NetCDF format is read in and aggregated to a
data.frame for statistical analysis with tools provided by the R
environment. The NetCDF format is not restricted to any specific type
of climate model. Global circulation models (GCMs), as the CMIP5 or
CMIP3 simulations, can be read in the same way as Regional Climate
Models (RCMs), as e.g. the CORDEX or ENSEMBLES simulations.
models2wux Reads NetCDF climate model output,
processes it, and writes the results to a data.frame which
is the backbone of all further WUX analyses
CMIP5fromESGF Automated downloading of the
CMIP5 multi-model climate ensemble
read.wux.table Reads in wux csv file obtained from
models2wux from harddisk and creates a data frame from
it (same data.frame as models2wux returns interactively)
AverageWuxDataFrame WUX data frame averaging function
Datasets:
userinput_CMIP5_changesignal,
userinput_CMIP5_timeseries,
modelinput_test Example config
files for models2wux
ensembles, ensembles_gcms,
cmip3_2050, cmip3_2100,
cmip5_2050, cmip5_2100,
CMIP5_example_changesignal,
CMIP5_example_timeseries,
alpinesummer
Example data frames
calculatated by models2wux
}summary.wux.df Summary statistics of the WUX
data frame (wux.df class)
plot.wux.df Scatter Plot
hist.wux.df Density Plot
plotAnnualCycle Annual Cycle Plot
}aovWux ANOVA for WUX data.frame
plot.wux.aov Barplot for aovWux
output
}method = "LES"), or iterative linear
reconstruction based on an ANOVA (method = "Iterative") or
Leave-one-out
cross-calculation (method = "IterativeCC").
reconstruct Linear reconstruction of missing
RCM-GCM combinations
}data.frame(the
so-called WUX data frame).